'use strict';

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var path = require('path');
var fs = require('fs');

var CONFIG_FILE_PATH = path.resolve(__dirname, './config.tmp.json');

/**
 * Write the config file on the disk
 *
 */
function write(config) {
  return new Promise(function (resolve, reject) {
    var data = JSON.stringify(config);

    fs.writeFile(CONFIG_FILE_PATH, data, function (err) {
      if (err) {
        reject(err);
      }

      resolve();
    });
  });
}

function shouldResolve(value) {
  return value && value.indexOf && value.indexOf('./') === 0;
}
/**
 * 
 * Resolves relative paths into absolute paths
 *
 */
function resolvePaths(values, rootPath) {
  for (var key in values) {
    var val = values[key];
    if (shouldResolve(val)) {
      values[key] = path.join(rootPath, values[key]);
    } else if ((typeof val === 'undefined' ? 'undefined' : _typeof(val)) === 'object') {
      resolvePaths(val, rootPath);
    }
  }

  if (values.length > 0) {
    values.forEach(function (value, idx) {
      if (shouldResolve(value)) {
        values[idx] = path.join(rootPath, value);
      }
    });
  }
}

module.exports = {
  write: write,
  resolvePaths: resolvePaths
};