'use strict';

var spawn = require('cross-spawn');
var scriptsPath = require.resolve('./scripts');
var reactHot = require('./reactHot');

var _require = require('./config'),
    resolvePaths = _require.resolvePaths,
    write = _require.write;

/**
 * Run the given script
 *
 */


function run(script, config) {
  var params = [];
  if (script === 'serve' && config.dashboard !== false) {
    params = params.concat([require.resolve('webpack-dashboard/bin/webpack-dashboard.js'), '--', 'node']);
  }
  params.push(scriptsPath);
  params.push(' ' + script);

  var options = { stdio: 'inherit' };

  var result = spawn.sync('node', params, options);
  process.exit(result.status);
}

/**
 * Write the config file and run a script ('serve', 'build', 'test')
 * @param {Object} config
 * @param {String} script - some like 'serve', 'build', 'test'
 * @return {Promise}
 */
function prepareAndRun(config, script) {
  // Resolve config paths
  resolvePaths(config, config.rootPath);

  // Enable cache by default
  if (config.cache !== false) {
    config.cache = true;
  }

  // Create the react hot loader entry point if it is enabled
  return reactHot.apply(config)
  // Write config file
  .then(function () {
    return write(config);
  })
  // Run the script
  .then(function () {
    return run(script, config);
  }).catch(function (err) {
    return console.log(err);
  });
}

module.exports = {
  prepareAndRun: prepareAndRun
};