'use strict';

var webpack = require('webpack');
var path = require('path');
var HappyPack = require('happypack');
var DashboardPlugin = require('webpack-dashboard/plugin');

var Logger = require('../util/logger');

var _require = require('./jsLoader'),
    getBabelQuery = _require.getBabelQuery;

var _require2 = require('./styleLoader'),
    sassLoaderConfig = _require2.sassLoaderConfig;

function applyProductionPlugins(plugins, config) {
  var pConfig = config.plugins || {};

  if (config.productionMode === false) {
    plugins.push(new webpack.DefinePlugin({
      "process.env": {
        NODE_ENV: JSON.stringify("production")
      }
    }));
  }

  if (pConfig.uglify !== false) {
    plugins.push(new webpack.optimize.UglifyJsPlugin({
      output: {
        comments: false
      }
    }));
  }

  if (pConfig.occurenceOrder !== false) {
    plugins.push(new webpack.optimize.OccurrenceOrderPlugin());
  }

  if (pConfig.dedupe === true) {
    plugins.push(new webpack.optimize.DedupePlugin());
  }

  return plugins;
}

/**
 *
 * @param {Sttring} env
 *
 */
function getPlugins(config) {
  var env = config.env;

  var plugins = [];

  if (env === 'dev' && config.reactHot) {
    plugins.push(new webpack.HotModuleReplacementPlugin());
  }

  // if (config.cache) {
  //   Logger.debug('Webpack cache enabled.');

  //   let query = getBabelQuery(config);

  //   plugins.push(new HappyPack({
  //     loaders: ['babel-loader?' + JSON.stringify(query)],
  //   }));
  // }

  if (env === 'prod') {
    applyProductionPlugins(plugins, config);
  }

  plugins.push(new webpack.LoaderOptionsPlugin({

    sassLoader: sassLoaderConfig(config),

    minimize: true,
    debug: false
  }));

  return plugins;
}

module.exports = getPlugins;